Stan Math Library: stan/math/rev/scal/fun/round.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

round.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_ROUND_HPP
2 #define STAN_MATH_REV_SCAL_FUN_ROUND_HPP
3
4 #include <math.h>
5 #include <stan/math/rev/core.hpp>
6 #include <boost/math/special_functions/fpclassify.hpp>
7 #include <limits>
8
9 namespace stan {
10 namespace math {
11
12 namespace {
13 class round_vari : public op_v_vari {
14 public:
15 explicit round_vari(vari* avi) :
16 op_v_vari(::round(avi->val_), avi) {
17 }
18 void chain() {
19 if (unlikely(boost::math::isnan(avi_->val_)))
20 avi_->adj_ = std::numeric_limits<double>::quiet_NaN();
21 }
22 };
23 }
24
57 inline var round(const var& a) {
58 return var(new round_vari(a.vi_));
59 }
60
61 }
62 }
63 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::round
fvar< T > round(const fvar< T > &x)
Definition: round.hpp:11
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
boost::math::isnan
bool isnan(const stan::math::var &v)
Checks if the given number is NaN.
Definition: boost_isnan.hpp:22
unlikely
#define unlikely(x)
Definition: likely.hpp:9
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43

[ Stan Home Page ] © 2011–2016, Stan Development Team.